summaryrefslogtreecommitdiffstats
path: root/src/include/usr/isteps/istep11list.H
diff options
context:
space:
mode:
authorPrachi Gupta <pragupta@us.ibm.com>2015-10-23 14:45:25 -0500
committerPatrick Williams <iawillia@us.ibm.com>2015-12-11 15:30:26 -0600
commit03b4d32d7d64ef2c25bb25869cf925d9afbace57 (patch)
treeeed892726db29f607c41667d9293b48b37fd3dc7 /src/include/usr/isteps/istep11list.H
parent7e5ca24a1eec65d3fdfba811c85f6f758277313e (diff)
downloadtalos-hostboot-03b4d32d7d64ef2c25bb25869cf925d9afbace57.tar.gz
talos-hostboot-03b4d32d7d64ef2c25bb25869cf925d9afbace57.zip
P9 Isteps: Created directory structure for istep 11/12 wrappers
Change-Id: I6e6e9677b524ca17c156adbc5168cfaffc9b1af8 RTC:137652 Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/21462 Tested-by: Jenkins Server Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/include/usr/isteps/istep11list.H')
-rw-r--r--src/include/usr/isteps/istep11list.H121
1 files changed, 119 insertions, 2 deletions
diff --git a/src/include/usr/isteps/istep11list.H b/src/include/usr/isteps/istep11list.H
index df30a3758..d5fc9afb6 100644
--- a/src/include/usr/isteps/istep11list.H
+++ b/src/include/usr/isteps/istep11list.H
@@ -27,7 +27,7 @@
/**
* list of functions called for ISTEP 11 according to Dean's
* IPL Flow Doc v0.60 (06/02/15)
*
*/
@@ -44,9 +44,90 @@
#include <initservice/initsvcreasoncodes.H>
// include prototypes file
-#include "../../../usr/hwpf/hwp/dmi_training/dmi_training.H"
#include <config.h>
+namespace ISTEP_11
+{
+
+/**
+ * @brief host prd hwreconfig
+ *
+ * param[in,out] - pointer to any arguments, usually NULL
+ *
+ * return any errlogs to istep
+ *
+ */
+void* call_host_prd_hwreconfig( void *io_pArgs );
+
+
+
+/**
+ * @brief cen sbe tp chiplet init1
+ *
+ * param[in,out] - pointer to any arguments, usually NULL
+ *
+ * return any errlogs to istep
+ *
+ */
+void* call_cen_sbe_tp_chiplet_init1( void *io_pArgs );
+
+
+
+/**
+ * @brief cen sbe pll initf
+ *
+ * param[in,out] - pointer to any arguments, usually NULL
+ *
+ * return any errlogs to istep
+ *
+ */
+void* call_cen_sbe_pll_initf( void *io_pArgs );
+
+/**
+ * @brief cen sbe pll setup
+ *
+ * param[in,out] - pointer to any arguments, usually NULL
+ *
+ * return any errlogs to istep
+ *
+ */
+void* call_cen_sbe_pll_setup( void *io_pArgs );
+
+
+/**
+ * @brief cen sbe tp chiplet init2
+ *
+ * param[in,out] - pointer to any arguments, usually NULL
+ *
+ * return any errlogs to istep
+ *
+ */
+void* call_cen_sbe_tp_chiplet_init2( void *io_pArgs );
+
+/**
+ * @brief cen sbe tp arrayinit
+ *
+ * param[in,out] - pointer to any arguments, usually NULL
+ *
+ * return any errlogs to istep
+ *
+ */
+void* call_cen_sbe_tp_arrayinit( void *io_pArgs );
+
+/**
+ * @brief cen sbe tp chiplet init3
+ *
+ * param[in,out] - pointer to any arguments, usually NULL
+ *
+ * return any errlogs to istep
+ *
+ */
+void* call_cen_sbe_tp_chiplet_init3( void *io_pArgs );
+
+
+};
+
+
namespace INITSERVICE
{
@@ -56,10 +137,46 @@ const TaskInfo g_istep11[] = {
NULL,
{ NONE, EXT_IMAGE, IPL_NOOP, false }
},
+ {
+ ISTEPNAME(11,01,"host_prd_hwreconfig"),
+ ISTEP_11::call_host_prd_hwreconfig,
+ { START_FN, EXT_IMAGE, NORMAL_IPL_OP, true }
+ },
+ {
+ ISTEPNAME(11,02,"cen_sbe_tp_chiplet_init1"),
+ ISTEP_11::call_cen_sbe_tp_chiplet_init1,
+ { START_FN, EXT_IMAGE, NORMAL_IPL_OP, true }
+ },
+ {
+ ISTEPNAME(11,03,"cen_sbe_pll_initf"),
+ ISTEP_11::call_cen_sbe_pll_initf,
+ { START_FN, EXT_IMAGE, NORMAL_IPL_OP, true }
+ },
+ {
+ ISTEPNAME(11,04,"cen_sbe_pll_setup"),
+ ISTEP_11::call_cen_sbe_pll_setup,
+ { START_FN, EXT_IMAGE, NORMAL_IPL_OP, true }
+ },
+ {
+ ISTEPNAME(11,05,"cen_sbe_tp_chiplet_init2"),
+ ISTEP_11::call_cen_sbe_tp_chiplet_init2,
+ { START_FN, EXT_IMAGE, NORMAL_IPL_OP, true }
+ },
+ {
+ ISTEPNAME(11,06,"cen_sbe_tp_arrayinit"),
+ ISTEP_11::call_cen_sbe_tp_arrayinit,
+ { START_FN, EXT_IMAGE, NORMAL_IPL_OP, true }
+ },
+ {
+ ISTEPNAME(11,07,"cen_sbe_tp_chiplet_init3"),
+ ISTEP_11::call_cen_sbe_tp_chiplet_init3,
+ { START_FN, EXT_IMAGE, NORMAL_IPL_OP, true }
+ },
};
const DepModInfo g_istep11Dependancies = {
{
+ DEP_LIB(libistep11.so),
NULL
}
};
@@ -27,7 +27,7 @@
/**
* list of functions called for ISTEP 11 according to Dean's
- * IPL Flow Doc v0.60 (06/02/15)
+ * IPL Flow Doc v0.67 (11/11/15)
*
*/
OpenPOWER on IntegriCloud